import { Button, Card, Drawer, Input, message, Steps, Typography } from "antd";
import { useEffect, useState } from "react";
import Guide from "./Guide";
import BasicForm from "./BasicForm";
import Chatpter from "./Chatpter";
import "./index.less";
import { useMediaStore } from "../../../store/media";
import { createCourse } from "../../../api";
import { ICourseBasic } from "../../../api/dto";
const { Text } = Typography;

interface ICourse {
  basicInfo: ICourseBasic;
  course_chapterList: [];
  course_guide: {
    guide_value: string;
    guide_html: string;
  };
}

const CourseCreate = () => {
  const [current, setCurrent] = useState(0);
  const [course, setCourse] = useState<ICourse>({
    basicInfo: {
      course_cover_url: "",
      course_title: "",
      course_summary: "",
    },
    course_chapterList: [],
    course_guide: {
      guide_value: "",
      guide_html: "",
    },
  });

  const onBasicFormChange = (form: any) =>
    setCourse((p) => ({ ...p, basicInfo: form }));

  const steps = [
    {
      title: "基本信息",
    },
    {
      title: "章节",
    },
    {
      title: "导读",
    },
  ];

  const items = steps.map((item) => ({ key: item.title, title: item.title }));

  const onChapterChange = (chapters: any) =>
    setCourse((p) => ({ ...p, course_chapterList: chapters }));

  const onGuideChange = ({ value, html }: { value: string; html: string }) => {
    setCourse((p) => ({
      ...p,
      course_guide: { guide_value: value, guide_html: html },
    }));
  };

  /**
   * 创建课程
   */
  const onClickCreate = () => {
    const { basicInfo, ...rest } = course;
    createCourse({ ...basicInfo, ...rest }).then((res) => {
      console.log(res);
    });
  };

  const mediaList = useMediaStore((s: any) => s.listFilter);

  const useFilter = useMediaStore((s: any) => s.useFilter);

  const [open, setOpen] = useState(false);

  const showDrawer = () => {
    setOpen(true);
  };

  const onClose = () => {
    setOpen(false);
  };

  const onSearchChange = (e: any) => {
    useFilter(e.target.value);
  };

  return (
    <div className="create-course">
      <Card>
        <Steps current={current} items={items} />
        <div className="content">
          <BasicForm
            onChange={onBasicFormChange}
            styles={{ display: current === 0 ? "block" : "none" }}
          />
          <Chatpter
            onChange={onChapterChange}
            styles={{ display: current === 1 ? "block" : "none" }}
          />
          <Guide
            onChange={onGuideChange}
            styles={{ display: current === 2 ? "block" : "none" }}
          />
        </div>
        <div style={{ textAlign: "right", marginTop: "40px" }}>
          {current === 1 && (
            <Button
              type="primary"
              onClick={showDrawer}
              style={{ marginRight: "12px" }}
            >
              视频库
            </Button>
          )}
          {current > 0 && (
            <Button
              style={{ marginRight: "12px" }}
              onClick={() => setCurrent(current - 1)}
            >
              上一步
            </Button>
          )}
          {current < steps.length - 1 && (
            <Button type="primary" onClick={() => setCurrent(current + 1)}>
              下一步
            </Button>
          )}
          {current === steps.length - 1 && (
            <Button type="primary" onClick={onClickCreate}>
              创建
            </Button>
          )}
        </div>
      </Card>
      <Drawer title="媒体库" placement="right" onClose={onClose} open={open}>
        <Input placeholder={`根据名称搜索`} onChange={onSearchChange} />
        <section style={{ marginTop: 24 }}>
          {mediaList.map((media: any) => {
            return (
              <div key={media.key} className="drawer-media-item">
                <div>{media.name}</div>
                <Text type="secondary">{media.key}</Text>
              </div>
            );
          })}
        </section>
      </Drawer>
    </div>
  );
};

export default CourseCreate;
