import { CloudSyncOutlined } from "@ant-design/icons";
import {
  Button,
  Card,
  Col,
  Row,
  Space,
  Table,
  Input,
  Segmented,
  Tooltip,
  Image,
  Typography,
  Modal,
  Tag,
} from "antd";
import dayjs from "dayjs";
import { useContext, useState } from "react";
import { getVod } from "../../../api";
import { useMount } from "../../../hooks";
import { useMediaStore } from "../../../store/media";
const { Paragraph, Text } = Typography;
const { Search } = Input;

const Library = () => {
  const [dataSource, setDataSource] = useState<any>([]);
  const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([]);

  const colors = [
    "magenta",
    "red",
    "volcano",
    "orange",
    "gold",
    "green",
    "cyan",
  ].reverse();

  const columns = [
    {
      title: "媒体文件名称",
      dataIndex: "name",
      key: "name",
      render: (_: any, record: any) => {
        return (
          <div>
            <Row>{record.name}</Row>
            <Row style={{ paddingTop: "5px" }}>
              {record.m3u8SubStreamList.map((item: any, index: number) => (
                <Tag key={item} color={colors[index]}>
                  {item}
                </Tag>
              ))}
            </Row>
            <Row style={{ paddingTop: "5px" }}>
              <Text type="secondary">时长: {record.duration}s</Text>
            </Row>
          </div>
        );
      },
    },
    {
      title: "FileID",
      dataIndex: "key",
      key: "key",
    },
    {
      title: "m3u8 大小",
      dataIndex: "m3u8Size",
      key: "m3u8Size",
    },
    {
      title: "状态",
      dataIndex: "status",
      key: "status",
    },
    {
      title: "创建时间",
      dataIndex: "createtime",
      key: "createtime",
    },

    {
      title: "m3u8",
      dataIndex: "m3u8",
      key: "m3u8",
    },
    {
      title: "视频封面图",
      dataIndex: "cover",
      key: "cover",
    },
    {
      title: "操作",
      dataIndex: "operation",
      key: "operation",
      render: (_: any, record: any) => {
        return (
          <Space>
            <a href={record.mp4} target="_blank">
              预览
            </a>
          </Space>
        );
      },
    },
  ];

  const onSelectChange = (newSelectedRowKeys: React.Key[]) => {
    console.log("selectedRowKeys changed: ", newSelectedRowKeys);
    setSelectedRowKeys(newSelectedRowKeys);
  };

  const rowSelection = { selectedRowKeys, onChange: onSelectChange };

  const onSearch = (value: string) => console.log(value);

  const computeMediaList = (mediaList: any) => {
    return mediaList.map((m: any) => ({
      key: m.FileId,
      mp4: m.BasicInfo.MediaUrl,
      m3u8: (
        <Paragraph style={{ margin: 0 }} copyable={{ text: m.AdaptStream.Url }}>
          复制
        </Paragraph>
      ),
      m3u8Size: (m.AdaptStream.Size / 1024 / 1024).toFixed(2) + " MB",
      m3u8SubStreamList: m.AdaptStream.SubStreamSet.map(
        (i: any) => i.Height + "p"
      ),
      name: m.BasicInfo.Name,
      duration: m.MetaData.Duration,
      cover: (
        <Paragraph
          style={{ margin: 0 }}
          copyable={{ text: m.BasicInfo.CoverUrl }}
        >
          复制
        </Paragraph>
      ),
      status: m.BasicInfo.Status,
      createtime: dayjs(m.BasicInfo.CreateTime).format("YYYY-MM-DD HH:mm:ss"),
    }));
  };

  const setMediaList = useMediaStore((s: any) => s.setList);

  /**
   * 最大每次5000条数据，估计这辈子也不可能了
   */
  const fetchVod = () => {
    getVod({ offset: 0, limit: 5000 }).then((process: any) => {
      const { mediaList, total } = process;
      setDataSource(computeMediaList(mediaList));
      setMediaList(computeMediaList(mediaList));
    });
  };

  useMount(() => {
    fetchVod();
  });

  return (
    <Card style={{ marginTop: 24 }}>
      <Row>
        <Col span={14}>
          <Space>
            <Search
              placeholder="根据名称搜索视频"
              onSearch={onSearch}
              style={{ width: 200 }}
            />
          </Space>
        </Col>
        <Col span={10} style={{ textAlign: "right" }}>
          <Space>
            <Text type="secondary">共计 {dataSource.length} 条媒体资源</Text>
            <Tooltip title="从腾讯云VOD同步全部视频" placement="left">
              <Button
                onClick={() => fetchVod()}
                type="primary"
                icon={<CloudSyncOutlined />}
              >
                同步
              </Button>
            </Tooltip>
          </Space>
        </Col>
      </Row>
      <Row style={{ marginTop: "16px" }}>
        <Col span={24}>
          <Table
            rowSelection={rowSelection}
            dataSource={dataSource}
            columns={columns}
          />
        </Col>
      </Row>
    </Card>
  );
};

export default Library;
