import {
  Button,
  Card,
  Col,
  Input,
  message,
  Row,
  Segmented,
  Space,
  Table,
} from "antd";
import "./index.less";
import { nanoid } from "nanoid";
import { useEffect, useState } from "react";
import { createXCode, selectXCodeList } from "../../api";
import { useMount } from "../../hooks";
import dayjs from "dayjs";

export default function InviteCode() {
  const [dataSource, setDataSource] = useState([]);

  const defaultColumns = [
    {
      title: "神秘代码",
      dataIndex: "code",
      key: "code",
      filters: [],
      filterSearch: true,
      onFilter: (value: string, record: any) => record.code.startsWith(value),
    },
    {
      title: "生成时间",
      dataIndex: "createtime",
      key: "createtime",
      defaultSortOrder: "descend",
      sorter: (a: any, b: any) => a.createtime - b.createtime,
      render: (_: any, record: any) => {
        return dayjs(+record.createtime).format("YYYY-MM-DD hh:mm:ss");
      },
    },
    {
      title: "失效时间",
      dataIndex: "expiretime",
      key: "expiretime",
      defaultSortOrder: "descend",
      sorter: (a: any, b: any) => a.expiretime - b.expiretime,
      render: (_: any, record: any) => {
        return dayjs(+record.expiretime).format("YYYY-MM-DD hh:mm:ss");
      },
    },
    {
      title: "绑定时间",
      dataIndex: "user_usetime",
      key: "user_usetime",
      render: (_: any, record: any) => {
        if (!!record.user_usetime)
          return dayjs(+record.user_usetime).format("YYYY-MM-DD hh:mm:ss");
      },
    },
    {
      title: "用户",
      dataIndex: "user_id",
      key: "user_id",
      render: (_: any, record: any) => {
        return record.user_id > 0
          ? `${record.user_login ?? ""}(${record.user_id})`
          : "";
      },
    },
    {
      title: "操作",
      dataIndex: "operation",
      key: "operation",
      render: () => {
        return <span>123</span>;
      },
    },
  ];

  const [columns, setColumns] = useState(defaultColumns);

  useEffect(() => {
    if (dataSource) {
      defaultColumns[0].filters = dataSource.map((i: any) => ({
        text: i.code.substring(0, 6) + "...",
        value: i.code,
      })) as any;
      setColumns(defaultColumns);
    }
  }, [dataSource]);

  const onClickGen = () => {
    if (!genRule.amount || !genRule.day) return message.error("生成规则错误");
    const params = [];
    for (let i = 0; i < genRule.amount; i++)
      params.push({
        code: nanoid(),
        expiretime: "" + (Date.now() + +genRule.day * 24 * 60 * 60 * 1000),
      });
    createXCode(params).then((res) => {
      console.log(res);
      setGenRule(defaultGenRule);
    });
  };

  const defaultGenRule = { day: 30, amount: 10 };

  const [genRule, setGenRule] = useState(defaultGenRule);

  const onSearch = (value: string) => console.log(value);

  useMount(() => {
    selectXCodeList().then((res: any) => {
      const { code, data } = res;
      if (code === 10000)
        setDataSource(data.map((i: any) => ({ ...i, key: i.code })));
    });
  });

  return (
    <div className="generate-invite-code">
      <Card>
        <Row>
          <Col span={12}>
            <Space>
              <Segmented options={["生", "熟"]} />
            </Space>
          </Col>
          <Col span={12} style={{ textAlign: "right" }}>
            <Space>
              <Input
                style={{ width: 80 }}
                placeholder="数量"
                suffix="个"
                value={genRule.amount}
                onChange={(e) =>
                  setGenRule((p: any) => ({
                    ...p,
                    amount: +e.target.value.replace(/[^\-?\d.]/g, ""),
                  }))
                }
              />
              <Input
                style={{ width: 100 }}
                placeholder="有效天数"
                suffix="天"
                value={genRule.day}
                onChange={(e) =>
                  setGenRule((p: any) => ({
                    ...p,
                    day: +e.target.value.replace(/[^\-?\d.]/g, ""),
                  }))
                }
              />
              <Button type="primary" onClick={onClickGen}>
                生成
              </Button>
            </Space>
          </Col>
        </Row>
        <Table
          style={{ marginTop: 24 }}
          dataSource={dataSource}
          columns={columns}
        />
      </Card>
    </div>
  );
}
