import { Body, Context, Controller, Inject, Post } from '@midwayjs/core';
import { BizCode } from '../biz/code';
import { CourseCreateDTO } from '../dto/course.dto';
import { ChapterService } from '../service/chapter.service';
import { CourseService } from '../service/course.service';
import { GuideService } from '../service/guide.service';

@Controller('/course')
export class CourseController {
  @Inject()
  ctx: Context;

  @Inject()
  courseService: CourseService;

  @Inject()
  chapterService: ChapterService;

  @Inject()
  guideService: GuideService;

  @Post('/create')
  async create(@Body() param: CourseCreateDTO) {
    try {
      const { course_chapterList, course_guide, ...rest } = param;
      const courseId = await this.courseService.create({ ...rest });
      await this.chapterService.create(
        course_chapterList.map((i: any) => ({
          ...i,
          chapter_course_id: courseId,
        }))
      );
      await this.guideService.create({
        ...course_guide,
        guide_course_id: courseId,
      });
      return { code: BizCode.OK };
    } catch (error) {
      this.ctx.logger.error(error);
      return {
        code: BizCode.ERROR,
        msg: `[error] course/create error happened`,
      };
    }
  }

  @Post('/select/all')
  async selectAll() {
    const courseList = await this.courseService.selectAll();
    return { code: BizCode.OK, data: courseList };
  }

  @Post('/chapter/select')
  async selectChapterByCourseId(@Body() params) {
    const { course_id } = params;
    const chapterList = await this.chapterService.select(course_id);
    const guide = await this.guideService.select(course_id);
    return { code: BizCode.OK, data: { chapterList, guide } };
  }
}
