import { Inject, Post, Body, Files, Controller, Context } from '@midwayjs/core';
import { BizCode } from '../biz/code';
import { VodSearchDTO } from '../dto/vod.dto';
import { uploadImagePromise } from '../util/vod';
import { IVodResponse } from '../interface';
import { VodService } from '../service/vod.service';

@Controller('/vod')
export class VodController {
  @Inject()
  ctx: Context;

  @Inject()
  vodService: VodService;

  /**
   * 腾讯媒资管理查询
   * API调用demo: https://console.cloud.tencent.com/api/explorer?Product=vod&Version=2018-07-17&Action=SearchMedia
   * 最大返回5000条数据
   */
  @Post('/media/select')
  async getCourseMediaList(@Body() param: VodSearchDTO) {
    const { offset: Offset = 0, limit: Limit = 5000, fileId } = param;
    try {
      // 单个媒体查询
      if (fileId) {
        const { data } = await this.vodService.selectMediaByFileId(fileId);
        if (data) return { code: BizCode.OK, data };
      }
      const { data } = await this.vodService.selectMediaList({ Offset, Limit });
      if (data) return { code: BizCode.OK, data };
    } catch (err) {
      this.ctx.logger.error(err);
      return { code: BizCode.ERROR, msg: '[error] vod create error' };
    }
  }

  /**
   * 后台管理：上传课程封面图
   */
  @Post('/course/cover/upload')
  async uploadCourseCoverImage(@Files() files) {
    const tmpPath = files[0].data;
    return await uploadImagePromise(tmpPath, +process.env.SUBAPPID)
      .then((data: IVodResponse) => ({ code: BizCode.OK, data }))
      .catch(err => {
        this.ctx.logger.error(err);
        throw new Error(err);
      });
  }

  /**
   * 图片单个上传
   */
  @Post('/oss/image/upload')
  async ossUploadImage(@Files() files) {
    const tmpPath = files[0].data;
    return await uploadImagePromise(tmpPath, +process.env.SUBAPPID_OSS)
      .then((data: IVodResponse) => ({
        code: BizCode.OK,
        data: { name: data.FileId, url: data.MediaUrl },
      }))
      .catch(err => {
        this.ctx.logger.error(err);
        return { code: BizCode.ERROR, msg: err };
      });
  }
}
