import {
  Middleware,
  IMiddleware,
  App,
  IMidwayApplication,
} from '@midwayjs/core';
import { NextFunction, Context } from '@midwayjs/koa';
import { BizCode } from '../biz/code';
import { adminSign, webSign } from '../config/base.config';
import { whiteApis } from '../config/white.api';
import { decodeToken } from '../util/encrypt';

@Middleware()
export class AuthMiddleware implements IMiddleware<Context, NextFunction> {
  @App()
  app: IMidwayApplication;

  resolve() {
    return async (ctx: Context, next: NextFunction) => {
      const isWhiteApi = whiteApis.some(api => ctx.url.indexOf(api) > -1);
      if (!isWhiteApi) {
        const token = ctx.cookies.get(adminSign) ?? ctx.cookies.get(webSign);
        try {
          const { hasLogin } = decodeToken(token);
          if (!hasLogin) return { code: BizCode.AUTH, msg: '身份验证错误' };
          await next();
        } catch (error) {
          return { code: BizCode.AUTH, msg: '身份验证错误' };
        }
      } else {
        await next();
      }
    };
  }

  static getName(): string {
    return 'auth';
  }
}
