import { Provide } from '@midwayjs/core';
import * as tencentcloud from 'tencentcloud-sdk-nodejs';

const VodClient = tencentcloud.vod.v20180717.Client;
const clientConfig = {
  credential: {
    secretId: process.env.SECRET_ID,
    secretKey: process.env.SECRET_KEY,
  },
  profile: {
    httpProfile: {
      endpoint: 'vod.tencentcloudapi.com',
    },
  },
};

@Provide()
export class VodService {
  /**
   * 根据FileId查询单个媒体资源
   */
  async selectMediaByFileId(fileId: string) {
    const client = new VodClient(clientConfig);
    const params = {
      SubAppId: +process.env.SUBAPPID,
      FileIds: [fileId],
    };
    return await client.SearchMedia(params).then(
      data => ({ data }),
      err => {
        throw new Error(err);
      }
    );
  }

  /**
   * 查询全部媒体列表
   */
  async selectMediaList({ Offset = 0, Limit = 5000 }) {
    const client = new VodClient(clientConfig);
    const params = {
      SubAppId: +process.env.SUBAPPID,
      Categories: ['Video'],
      Offset,
      Limit,
    };
    return await client.SearchMedia(params).then(
      data => ({ data }),
      err => {
        throw new Error(err);
      }
    );
  }
}
