import { useEffect, useState } from "react";
import "./index.less";
import { ResizeBox, Space, Result, Button } from "@arco-design/web-react";
import Guide from "./components/Guide";
import { useMount } from "../../hook";
import Player from "./components/DPlayer";
import { useParams } from "react-router-dom";
import { getChapterGuideById } from "../../api";
import { ms2Time } from "./util";

function CourseDetail() {
  const { id: course_id = "" } = useParams();
  const [toc, setToc] = useState([]);
  const [view, setView] = useState<any>(null);

  useMount(() => {
    if (!!course_id)
      getChapterGuideById(course_id).then((res) => {
        const { data } = res;
        const processToc = data?.chapterList.map((item: any) => {
          return {
            title: item.chapter_title,
            level: +item.chapter_level,
            time: ms2Time(+item.media_time),
            active: false,
            view: (
              <Player
                video={{ url: item.media_url, pic: item.media_cover_url }}
              />
            ),
          };
        });
        const append = [
          {
            title: "导读",
            level: 1,
            time: "",
          },
          {
            title: "介绍 / 下载",
            level: 2,
            time: "",
            active: true,
            view: <Guide html={data?.guide.guide_html} />,
          },
          ...processToc,
        ];
        setToc(append as any);
        setView(<Guide html={data?.guide.guide_html} />);
      });
  });

  const onclickItem = (i: any) => {
    setToc((t: any) =>
      t.map((p: any) => ({ ...p, active: i.title === p.title }))
    );
    setView(
      i.view ?? (
        <Result
          status="403"
          subTitle="无权访问"
          extra={<Button type="text">订阅</Button>}
        />
      )
    );
  };

  return (
    <div className="course-detail">
      <ResizeBox.Split
        direction="horizontal"
        style={{ height: "calc(100vh - 60px)" }}
        max={0.9}
        min={0.1}
        size={0.2}
        panes={[
          <aside className="table-of-content">
            <h2>云顶计划：K线</h2>
            <div>
              <Space style={{ color: "var(--color-text-3)" }}>
                <span>2023年3月2日</span>
              </Space>
            </div>
            <div className="toc">
              {toc.map((i: any) => {
                if (i.level === 1) {
                  return (
                    <div className="level-1" key={i.title}>
                      {i.title}
                    </div>
                  );
                } else if (i.level === 2) {
                  return (
                    <div
                      className={`level-2 ${i.active ? "active" : ""}`}
                      key={i.title}
                      onClick={() => onclickItem(i)}
                    >
                      <span className="bs-ellipsis">{i.title}</span>
                      <span className="time">{i.time}</span>
                    </div>
                  );
                }
              })}
            </div>
          </aside>,
          view,
        ]}
      />
    </div>
  );
}

export default CourseDetail;
